==> gtktalog-0.1.0.tar.gz: gtktalog-0.1.0/src/gtktalog/categories.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __CATEGORIES_H__
#define __CATEGORIES_H__

#include <config.h>
#include <gnome.h>
#include "config_common.h"

typedef struct
{
  GtkWidget *cat_window;
  GtkWidget *cat_clist;
  gint selected_row;
  gpointer tmpdata;
  guint cat_id, tmpcount;
}
CATEGORY_WIDGETS;

void _set_category_name(gchar *string, gpointer data);
void add_the_categorie(GtkWidget *w, gpointer data);
void edit_the_categorie(GtkWidget *w, gpointer data);
void del_the_categorie(GtkWidget *w, gpointer data);
void cat_selected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
void cat_unselected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
gboolean category_count(GNode *gn, gpointer data);
GList *make_categories_list(CONFIG *my_config);
void edit_categories(GtkWidget *w, gpointer data);

#endif

==> gtktalog-0.13.2.tar.gz: gtktalog-0.13.2/src/gtktalog/categories.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __CATEGORIES_H__
#define __CATEGORIES_H__

#include <config.h>
#include <gnome.h>
#include "config_common.h"


void _set_category_name(gchar *string, gpointer data);
void add_the_categorie(GtkWidget *w, FOLDER *racine);
void edit_the_categorie(GtkWidget *w, FOLDER *racine);
void del_the_categorie(GtkWidget *w, FOLDER *racine);
void cat_selected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
void cat_unselected(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
gboolean category_count (GNode * gn, gpointer data);
GList *make_categories_list(FOLDER * racine);
void remove_unused_categories (FOLDER * racine);
void edit_categories (FOLDER *racine);

#endif
